/*
This file is part of DeNa Drive.

DeNa Drive is free software: you can redistribute it and/or modify it under the terms of the
GNU General Public License as published by the Free Software Foundation,
either version 3 of the License, or (at your option) any later version.

DeNa Drive is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with DeNa Drive.
If not, see <https://www.gnu.org/licenses/>.
*/

/**
 * This file contains the MainActivity activity.
 * The activity is responsible for the everyday usage of the app.
 * It provides a UI to do all sort of operations
 */

package com.bbc.denadrive

import android.os.Bundle
import android.util.Log
import android.widget.Toast
import androidx.activity.ComponentActivity
import androidx.activity.addCallback
import androidx.activity.compose.setContent
import com.bbc.denadrive.apihandlers.ResponsesViewer
import com.bbc.denadrive.filehandling.FileDownloader
import com.bbc.denadrive.home.ScaffoldWithSidebar
import com.bbc.denadrive.oauth.AuthStatePersistence

class MainActivity : ComponentActivity() {

    private lateinit var responsesViewer: ResponsesViewer
    private val exportSupportedFiles: List<String> = listOf(
        "document",
        "drawing",
        "presentation",
        "spreadsheet",
    )

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        responsesViewer = ResponsesViewer()

        DriveRequester.populateTree(this, responsesViewer.folderTree)

        Log.e("vediamo", AuthStatePersistence.retrieveAuthState(this).jsonSerializeString())

        onBackPressedDispatcher.addCallback(this) {
            if (responsesViewer.currentFolderTree.value.parent != null) {
                responsesViewer.currentFolderTree.value =
                    responsesViewer.currentFolderTree.value.parent!!
            } else {
                finish()
            }
        }
        val fileDownloader = FileDownloader(this)


        setContent {
//            val navController = rememberNavController()
            ScaffoldWithSidebar(
                responsesViewer,
                { file ->
                    Toast.makeText(
                        this,
                        "You pressed the file ${file.name}",
                        Toast.LENGTH_SHORT
                    ).show()
                    /*if (file.mimeType.substringAfterLast(".") in exportSupportedFiles) {
                        Log.e("MYTAG", "Supported!", )
                        fileDownloader.downloadFile(
                            file,
                            exported = true
                        )
                    } else {
                        Toast.makeText(
                            this,
                            "This file has no default action. Download support coming soon",
                            Toast.LENGTH_SHORT
                        ).show()
                    }*/
                    fileDownloader.downloadFile(
                        file,
                        exported = file.mimeType.substringAfterLast(".") in exportSupportedFiles
                    )
                },
                { folder ->
                    responsesViewer.currentFolderTree.value =
                        responsesViewer.currentFolderTree.value.stepForward(folder.id)
                }
            ) {
                responsesViewer.toggleUpdaters()
                DriveRequester.makeNewRequest(
                    this,
                    "https://people.googleapis.com/v1/people/me?personFields=emailAddresses",
                    {}) { resp, ex ->
                    if (ex != null) {
                        Log.e("noGood", "$ex")
                    } else {
                        Log.e("good", "$resp")
                    }
                }
            }
        }
    }
}

//@Composable
//fun Greeting(name: String, modifier: Modifier = Modifier) {
//    Text(
//        text = "Hello $name!",
//        modifier = modifier
//    )
//}
//
//@Preview(showBackground = true)
//@Composable
//fun GreetingPreview() {
//    DeNaDriveTheme {
//        Greeting("Android")
//    }
//}